@@ -374,9 +374,9 @@ get_dpar <- function(draws, dpar, i = NULL, ilink = NULL) {
   if (is.list(x)) {
     # compute samples of a predicted parameter
     if (!is.null(x$nlpars)) {
-      out <- nonlinear_predictor(x, i = i)
+      out <- nonlinear_predictor(x, i = i, fdraws = draws)
     } else {
-      out <- linear_predictor(x, i = i)
+      out <- linear_predictor(x, i = i, fdraws = draws)
     }
     if (is.null(ilink)) {
       ilink <- apply_dpar_ilink(dpar, family = draws$f)
@@ -384,14 +384,14 @@ get_dpar <- function(draws, dpar, i = NULL, ilink = NULL) {
     if (ilink) {
       out <- ilink(out, x$f$link)
     }
-  } else if (!is.null(i) && isTRUE(ncol(x) > 1L)) {
+    if (length(i) == 1L) {
+      out <- index_col(out, 1)
+    }
+  } else if (!is.null(i) && !is.null(dim(x))) {
     out <- index_col(x, i)
   } else {
     out <- x
   }
-  if (is.matrix(out) && ncol(out) == 1L) {
-    out <- as.vector(out)
-  }
   if (dpar == "sigma" && !isTRUE(grepl("_cov$", draws$f$fun))) {
     # 'se' will be incorporated directly into 'sigma'
     if (!isTRUE(attr(x, "se_added")) && "se" %in% names(draws$data)) {
@@ -445,7 +445,7 @@ get_Mu <- function(draws, i = NULL) {
       Mu <- do.call(abind, c(Mu, along = 3))
     }
   } else {
-    # at this point we now that i is not NULL
+    stopifnot(!is.null(i))
     Mu <- index_col(Mu, i)
   }
   Mu
@@ -477,7 +477,7 @@ get_Sigma <- function(draws, i = NULL) {
       }
     }
   } else {
-    # at this point we know that i is not NULL
+    stopifnot(!is.null(i))
     ldim <- length(dim(Sigma))
     stopifnot(ldim %in% 3:4)
     if (ldim == 4L) {
@@ -495,8 +495,9 @@ get_se <- function(draws, i = NULL) {
   if (!is.null(se)) {
     if (!is.null(i)) {
       se <- se[i]
-    } else {
-      dim <- c(draws$nsamples, draws$nobs)
+    }
+    if (length(se) > 1L) {
+      dim <- c(draws$nsamples, length(se))
       se <- as_draws_matrix(se, dim = dim)
     }
   } else {
@@ -646,175 +647,6 @@ extract_pars <- function(pars, all_pars, exact_match = FALSE,
   pars
 }
 
-find_names <- function(x) {
-  # find all valid object names in a string 
-  # Args:
-  #   x: a character string
-  # Notes:
-  #   Does not use the R parser itself to allow for double points, 
-  #   square brackets and kommas at the end of names.
-  #   currently only used in 'hypothesis_internal'
-  # Returns:
-  #   all valid variable names within the string
-  if (!is.character(x) || length(x) > 1) {
-    stop2("Argument 'x' must be a character string of length one.")
-  }
-  x <- gsub("[[:space:]]", "", x)
-  regex_all <- "([^([:digit:]|[:punct:])]|\\.)[[:alnum:]_\\.\\:]*"
-  regex_all <- paste0(regex_all, "(\\[[^],]+(,[^],]+)*\\])?")
-  pos_all <- gregexpr(regex_all, x)[[1]]
-  regex_fun <- "([^([:digit:]|[:punct:])]|\\.)[[:alnum:]_\\.]*\\("
-  pos_fun <- gregexpr(regex_fun, x)[[1]]
-  pos_decnum <- gregexpr("\\.[[:digit:]]+", x)[[1]]
-  pos_var <- list(rmMatch(pos_all, pos_fun, pos_decnum))
-  unlist(regmatches(x, pos_var))
-}
-
-evidence_ratio <- function(x, cut = 0, wsign = c("equal", "less", "greater"), 
-                           prior_samples = NULL, pow = 12, ...) {
-  # compute the evidence ratio between two disjunct hypotheses
-  # Args:
-  #   x: posterior samples 
-  #   cut: the cut point between the two hypotheses
-  #   wsign: direction of the hypothesis
-  #   prior_samples: optional prior samples for undirected hypothesis
-  #   pow: influences the accuracy of the density
-  #   ...: optional arguments passed to density.default
-  # Returns:
-  #   the evidence ratio of the two hypothesis
-  wsign <- match.arg(wsign)
-  if (wsign == "equal") {
-    if (is.null(prior_samples)) {
-      out <- NA
-    } else {
-      dots <- list(...)
-      dots <- dots[names(dots) %in% names(formals("density.default"))]
-      args <- c(list(n = 2^pow), dots)
-      eval_dens <- function(x) {
-        # evaluate density of x at cut
-        from <- min(x)
-        to <- max(x)
-        if (from > cut) {
-          from <- cut - sd(x) / 4
-        } else if (to < cut) {
-          to <- cut + sd(x) / 4
-        }
-        dens <- do.call(density, c(nlist(x, from, to), args))
-        spline(dens$x, dens$y, xout = cut)$y
-      }
-      out <- eval_dens(x) / eval_dens(prior_samples)
-    }
-  } else if (wsign == "less") {
-    out <- length(which(x < cut))
-    out <- out / (length(x) - out)
-  } else if (wsign == "greater") {
-    out <- length(which(x > cut))
-    out <- out / (length(x) - out)  
-  }
-  out
-}
-
-hypothesis_internal <- function(x, hypothesis, class = "", alpha = 0.05, ...) {
-  # internal function to evaluate hypotheses
-  # Args:
-  #   x: the primary object passed to the hypothesis method;
-  #      Needs to be a brmsfit object or coercible to a data.frame
-  #   hypothesis: Vector of character strings containing the hypotheses
-  #   class: prefix of the parameters in the hypotheses
-  #   alpha: alpha-level
-  # Returns:
-  #   an object of class 'brmshypothesis'
-  if (!is.character(hypothesis)) {
-    stop2("Argument 'hypothesis' must be a character vector.")
-  }
-  if (!is.character(class) || length(class) != 1L) {
-    stop2("Argument 'class' must be a single character string.")
-  }
-  if (length(alpha) != 1L || alpha < 0 || alpha > 1) {
-    stop2("Argument 'alpha' must be a single value in [0,1].")
-  }
-  
-  .eval_hypothesis <- function(h) {
-    stopifnot(length(h) == 1L && is.character(h))
-    # parse hypothesis string
-    h <- gsub("[ \t\r\n]", "", h)
-    sign <- get_matches("=|<|>", h)
-    lr <- get_matches("[^=<>]+", h)
-    if (length(sign) != 1L || length(lr) != 2L) {
-      stop2("Every hypothesis must be of the form 'left (= OR < OR >) right'.")
-    }
-    h <- paste0("(", lr[1], ")")
-    h <- paste0(h, ifelse(lr[2] != "0", paste0("-(", lr[2], ")"), ""))
-    varsH <- unique(find_names(h))
-    parsH <- paste0(class, varsH)
-    miss_pars <- setdiff(parsH, pars)
-    if (length(miss_pars)) {
-      miss_pars <- collapse_comma(miss_pars)
-      stop2("Some parameters cannot be found in the model: \n", miss_pars)
-    }
-    # rename hypothesis for correct evaluation
-    h_renamed <- rename(h, c(":", "[", "]", ","),  c("___", ".", ".", ".."))
-    # get posterior and prior samples
-    symbols <- c(paste0("^", class), ":", "\\[", "\\]", ",")
-    subs <- c("", "___", ".", ".", "..")
-    samples <- posterior_samples(x, pars = parsH, exact_match = TRUE)
-    names(samples) <- rename(names(samples), symbols, subs, fixed = FALSE)
-    samples <- as.matrix(eval2(h_renamed, samples))
-    prior_samples <- prior_samples(x, pars = parsH, fixed = TRUE)
-    if (!is.null(prior_samples) && ncol(prior_samples) == length(varsH)) {
-      names(prior_samples) <- rename(
-        names(prior_samples), symbols, subs, fixed = FALSE
-      )
-      prior_samples <- as.matrix(eval2(h_renamed, prior_samples))
-    } else {
-      prior_samples <- NULL
-    }
-    # summarize hypothesis
-    wsign <- switch(sign, "=" = "equal", "<" = "less", ">" = "greater")
-    probs <- switch(sign, 
-      "=" = c(alpha / 2, 1 - alpha / 2), 
-      "<" = c(0, 1 - alpha), ">" = c(alpha, 1)
-    )
-    sm <- lapply(
-      c("mean", "sd", "quantile", "evidence_ratio"), 
-      get_estimate, samples = samples, probs = probs, 
-      wsign = wsign, prior_samples = prior_samples
-    )
-    sm <- as.data.frame(matrix(unlist(sm), nrow = 1))
-    if (sign == "<") {
-      sm[1, 3] <- -Inf
-    } else if (sign == ">") {
-      sm[1, 4] <- Inf
-    }
-    sm <- cbind(sm, ifelse(!(sm[1, 3] <= 0 && 0 <= sm[1, 4]), '*', ''))
-    rownames(sm) <- paste(h, sign, "0")
-    cl <- (1 - alpha) * 100
-    colnames(sm) <- c(
-      "Estimate", "Est.Error", paste0("l-", cl, "% CI"),
-      paste0("u-", cl, "% CI"), "Evid.Ratio", "Star"
-    )
-    if (is.null(prior_samples)) {
-      prior_samples <- as.matrix(rep(NA, nrow(samples)))
-    }
-    return(nlist(summary = sm, samples, prior_samples))
-  }
-  
-  pars <- parnames(x)[grepl("^", class, parnames(x))]
-  hlist <- lapply(hypothesis, .eval_hypothesis)
-  hs <- do.call(rbind, lapply(hlist, function(h) h$summary))
-  samples <- as.data.frame(
-    do.call(cbind, lapply(hlist, function(h) h$samples))
-  )
-  prior_samples <- as.data.frame(
-    do.call(cbind, lapply(hlist, function(h) h$prior_samples))
-  )
-  names(samples) <- names(prior_samples) <- paste0("H", seq_along(hlist))
-  class <- sub("_+$", "", class)
-  out <- nlist(hypothesis = hs, samples, prior_samples, class, alpha)
-  class(out) <- "brmshypothesis"
-  out
-}
-
 add_samples <- function(x, newpar, dim = numeric(0), dist = "norm", ...) {
   # add some random samples to a brmsfit object 
   # currently only used within tests
